==> Nikola-7.7.7-py2.py3-none-any.whl: nikola/data/themes/base/messages/messages_tr.py <==
# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d dakikalık okuma",
    "(active)": "(etkin)",
    "Also available in:": "Şu dilde de mevcut:",
    "Archive": "Arşiv",
    "Authors": "Yazarlar",
    "Categories": "Kategoriler",
    "Comments": "Yorumlar",
    "LANGUAGE": "Türkçe",
    "Languages:": "Diller:",
    "More posts about %s": "%s ilgili diğer yazılar",
    "Newer posts": "Daha yeni yazılar",
    "Next post": "Sonraki yazı",
    "No posts found.": "Yazı bulunamadı.",
    "Nothing found.": "Hiçbir şey bulunamadı.",
    "Older posts": "Daha eski yazılar",
    "Original site": "Orjinal web sayfası",
    "Posted:": "Yayın tarihi:",
    "Posts about %s": "%s ile ilgili yazılar",
    "Posts by %s": "%s tarafından yazılar",
    "Posts for year %s": "%s yılındaki yazılar",
    "Posts for {month} {day}, {year}": "{month} {day}, {year} 'den beri olan yazılar",
    "Posts for {month} {year}": "{month} {year} göre yazılar",
    "Previous post": "Önceki yazı",
    "Publication date": "Yayınlanma tarihi",
    "RSS feed": "RSS kaynağı",
    "Read in English": "Türkçe olarak oku",
    "Read more": "Devamını oku",
    "Skip to main content": "Ana içeriğe geç",
    "Source": "Kaynak",
    "Subcategories:": "Altkategoriler:",
    "Tags and Categories": "Etiketler ve Kategoriler",
    "Tags": "Etiketler",
    "Uncategorized": "Kategorisiz",
    "Updates": "Güncellemeler",
    "Write your page here.": "Sayfanızı buraya yazın.",
    "Write your post here.": "Yazınızı buraya yazın.",
    "old posts, page %d": "eski yazılar, sayfa %d",
    "page %d": "sayfa %d",
}

==> Nikola-7.8.1-py2.py3-none-any.whl: nikola/data/themes/base/messages/messages_tr.py <==
# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d dakikalık okuma",
    "(active)": "(etkin)",
    "Also available in:": "Şu dilde de mevcut:",
    "Archive": "Arşiv",
    "Authors": "Yazarlar",
    "Categories": "Kategoriler",
    "Comments": "Yorumlar",
    "LANGUAGE": "Türkçe",
    "Languages:": "Diller:",
    "More posts about %s": "%s hakkında diğer yazılar",
    "Newer posts": "Daha yeni yazılar",
    "Next post": "Sonraki yazı",
    "No posts found.": "Yazı bulunamadı.",
    "Nothing found.": "Hiçbir şey bulunamadı.",
    "Older posts": "Daha eski yazılar",
    "Original site": "Orjinal web sayfası",
    "Posted:": "Yayın tarihi:",
    "Posts about %s": "%s ile ilgili yazılar",
    "Posts by %s": "%s tarafından yazılanlar",
    "Posts for year %s": "%s yılındaki yazılar",
    "Posts for {month} {day}, {year}": "{month} {day}, {year} tarihinden itibaren yazılar",
    "Posts for {month} {year}": "{month} {year} göre yazılar",
    "Previous post": "Önceki yazı",
    "Publication date": "Yayınlanma tarihi",
    "RSS feed": "RSS kaynağı",
    "Read in English": "Türkçe olarak oku",
    "Read more": "Devamını oku",
    "Skip to main content": "Ana içeriğe geç",
    "Source": "Kaynak",
    "Subcategories:": "Alt kategoriler:",
    "Tags and Categories": "Etiketler ve Kategoriler",
    "Tags": "Etiketler",
    "Toggle navigation": "",
    "Uncategorized": "Kategorisiz",
    "Updates": "Güncellemeler",
    "Write your page here.": "Sayfanızı buraya yazın.",
    "Write your post here.": "Yazınızı buraya yazın.",
    "old posts, page %d": "eski yazılar, sayfa %d",
    "page %d": "sayfa %d",
}
